            <div class="user-dashboard">
                <div class="container">
                <div class="col-xl-12 col-lg-12">
                    <div class="row">
                        <div class="col-6"> 
                            <h3>Area Names</h3>
                         </div>
                         <div class="col-6" style="text-align: right;"> 
                            <button class="btn-save" onclick="addform()">New</button>
                         </div>
                        </div>                                                 
                        </div>
                   <div class="row">
                <div class="col-xl-12 col-lg-12">
                    <div class="transactions-table table">
                        <div class="table">
                            <table id="example" class="table" style="width:100%">
                                <thead>
                                    <tr>
                                        <th>Code</th>
                                        <th>Area Name</th>
                                        <th>District Name</th>
                                        <th>State Name</th>
                                        <th>Status</th>
                                        <th></th>
                                        <th></th>
                                    </tr>
                                </thead>
                                <tbody>
                                     <tr>
                                        <td></td>                                                          
                                        <td></td>           
                                        <td></td>
                                        <td></td>
                                        <td style="width: 70px;"><a href="javascript:void(0)" onclick="editform()" class="btn-save">Edit</a></td>
                                        <td style="width: 70px;"><a href="javascript:void(0)" onclick="viewform()" class="btn-save">View</a></td>
                                     </tr>
                                   </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
            </div>
</div>

<div class="modal fade" id="confirmationtoadd" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">New Area NAme</h5>
                <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                <div class="row">
                    <div class="col-6">
                        <label class="form-label">Code</label><span style='color:red'>*</span>
                        <input class="form-control form-control-sm" type="text" id="Code" name="Code" placeholder="Code" value="" onkeypress="clearInput('Code')">
                        <span id="ErrCode" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Country Name</label><span style='color:red'>*</span>
                         <select class="form-select form-select-sm" name="CountryName" id="CountryName" onchange="clearInput('CountryName')">
                            <option value="0">Select Country Name</option>
                            <option value="1">Country Name</option>
                         </select>
                        <span id="ErrCountryName" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">State Name</label><span style='color:red'>*</span>
                         <select class="form-select form-select-sm" name="StateName" id="StateName" onchange="clearInput('StateName')">
                            <option value="0">Select State Name</option>
                            <option value="1">State Name</option>
                         </select>
                        <span id="ErrStateName" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">District Name</label><span style='color:red'>*</span>
                         <select class="form-select form-select-sm" name="DistrictName" id="DistrictName" onchange="clearInput('DistrictName')">
                            <option value="0">Select District Name</option>
                            <option value="1">District Name</option>
                         </select>
                        <span id="ErrDistrictName" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Area Name</label><span style='color:red'>*</span>
                        <input class="form-control form-control-sm" type="text" id="AreaName" name="AreaName" placeholder="Area Name" value="" onkeypress="clearInput('AreaName')">
                        <span id="ErrAreaName" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Remarks</label>
                        <input class="form-control form-control-sm" type="text" id="Remarks" name="Remarks" placeholder="Remarks" value="" onkeypress="clearInput('Remarks')">
                        <span id="ErrRemarks" class="error_msg" style="color: red;"></span>
                    </div>
                </div>
            </div>
            <div class="modal-footer">
                 <button type="button" data-dismiss="modal"  class="btn-cancel">Cancel</button>
                 <button type="button" href="javascript:void(0)" onclick="add()"  class="btn-save">Save</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>
                                                                                                            
<div class="modal fade" id="confirmationtoedit" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">Edit Area Name</h5>
                <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                <div class="row">
                    <div class="col-6">
                        <label class="form-label">Code</label><span style='color:red'>*</span>
                        <input class="form-control form-control-sm" type="text" id="editCode" name="Code" placeholder="Code" value="<?php echo $data[0]['Code'];?>" onkeypress="clearInput('editCode')">
                        <span id="ErreditCode" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Country Name</label><span style='color:red'>*</span>
                         <select class="form-select form-select-sm" name="CountryName" id="editCountryName" value="<?php echo $data[0]['Country'];?>" onchange="clearInput('editCountryName')">
                            <option value="0"> Select Country Name</option>
                            <option value="1"> Country Name</option>
                         </select>
                        <span id="ErreditCountryName" class="error_msg" style="color: red;"></span>
                    </div>
                     <div class="col-12">
                        <label class="form-label">State Name</label><span style='color:red'>*</span>
                         <select class="form-select form-select-sm" name="StateName" id="editStateName" value="<?php echo $data[0]['StateName'];?>" onchange="clearInput('editStateName')">
                            <option value="0">Select State Name</option>
                            <option value="1">State Name</option>
                         </select>
                        <span id="ErreditStateName" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">District Name</label><span style='color:red'>*</span>
                         <select class="form-select form-select-sm" name="DistrictName" id="editDistrictName" value="<?php echo $data[0]['DistrictName'];?>" onchange="clearInput('editDistrictName')">
                            <option value="0">Select District Name</option>
                            <option value="1">District Name</option>
                         </select>
                        <span id="ErreditDistrictName" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Area Name</label><span style='color:red'>*</span>
                        <input class="form-control form-control-sm" type="text" id="editAreaName" name="AreaName" placeholder="Area Name" value="<?php echo $data[0]['AreaName'];?>" onkeypress="clearInput('editAreaName')">
                        <span id="ErreditAreaName" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-sm-6">
                        <label class="form-label">Status</label><span style='color:red'>*</span>
                        <select name="Status" id="editStatus" class="form-select form-select-sm">
                            <option value="1" <?php echo ($data[0]['Status']==1) ? " selected='selected' ": "''";?>>Active</option>
                            <option value="0" <?php echo ($data[0]['Status']==0) ? " selected='selected' ": "''";?>>DeActive</option>
                        </select>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Remarks</label>
                        <input class="form-control form-control-sm" type="text" id="editRemarks" name="Remarks" placeholder="Remarks" value="<?php echo $data[0]['Remarks'];?>" onkeypress="clearInput('editRemarks')">
                        <span id="ErreditRemarks" class="error_msg" style="color: red;"></span>
                    </div>
                    </div>
            </div>
            <div class="modal-footer">
                <button type="button" data-dismiss="modal"  class="btn-cancel">Cancel</button>
                 <button type="button" href="javascript:void(0)" onclick="edit()"  class="btn-save">Update</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>

<div class="modal fade" id="confirmationtoview" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">View Area Name</h5>
               <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                <div class="row">
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">Code</div>
                        <?php echo $data[0]['Code'];?>
                    </div>
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">Country Name</div>
                        <?php echo $data[0]['CountryName'];?>
                    </div>
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">State Name</div>
                        <?php echo $data[0]['StateName'];?>
                    </div>
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">District Name</div>
                        <?php echo $data[0]['DistrictName'];?>
                    </div>
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">Area Name</div>
                        <?php echo $data[0]['AreaName'];?>
                    </div>
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">Remarks</div>
                        <?php echo $data[0]['Remarks'];?>
                    </div>
                    <div class="col-sm-6">
                        <div style="font-weight: bold;">Status</div>
                        <?php echo $data[0]['Status'];?>
                    </div>
                    <div class="col-sm-6">
                        <div style="font-weight: bold;">Created On</div>
                        <?php echo $data[0]['CreatedOn'];?>
                    </div>
                </div>
            </div>
            <div class="modal-footer"> 
                 <button type="button" data-dismiss="modal"  class="btn-cancel">Cancel</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>

<div class="modal fade" id="Success" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-body" style="text-align: center;">
                <div id="sucess">
                    <img id="Sucess" style="width: 150px;" src="assets/sucess.gif" alt=""/>
                </div>
                <h3 class="title">Success.</h3>  
                 <button type="button" href="javascript:void(0)" onclick="dashboard()"  class="btn-save">Continue</button>         
            </div>
        </div>
    </div>
</div>
     
<script>
function view(){
      $('#confirmation').modal("show"); 
      
}

function addform(){
     $('#confirmationtoadd').modal("show");
     $('#Code').val(""); 
     $('#CountryName').val("0");                   
     $('#StateName').val("0"); 
     $('#DistrictName').val("0"); 
     $('#AreaName').val(""); 
     $('#Remarks').val("");
     
     $('#ErrCode').html(""); 
     $('#ErrCountryName').html(""); 
     $('#ErrStateName').html(""); 
     $('#ErrDistrictName').html(""); 
     $('#ErrAreaName').html(""); 
     $('#ErrRemarks').html("");
      
     $("#Code").removeClass("highlight_error"); 
     $("#CountryName").removeClass("highlight_error"); 
     $("#StateName").removeClass("highlight_error"); 
     $("#DistrictName").removeClass("highlight_error"); 
     $("#AreaName").removeClass("highlight_error"); 
     $("#Remarks").removeClass("highlight_error"); 
     
}

function add(){
    var error = 0;
       if ($('#Code').val()==""){
            $('#ErrCode').html("Please enter Code");
         $("#Code").addClass("highlight_error"); 
            error++;
    }  else {
         $("#Code").removeClass("highlight_error"); 
            $('#ErrCode').html(""); 
    }
     if ($('#CountryName').val()=="0"){
            $('#ErrCountryName').html("Please select Country Name");
         $("#CountryName").addClass("highlight_error"); 
           error++;
    }  else {
         $("#CountryName").removeClass("highlight_error"); 
            $('#ErrCountryName').html(""); 
    } 
    if ($('#StateName').val()=="0"){
            $('#ErrStateName').html("Please select State Name");
         $("#StateName").addClass("highlight_error"); 
           error++;
    }  else {
         $("#StateName").removeClass("highlight_error"); 
            $('#ErrStateName').html(""); 
    }
     if ($('#DistrictName').val()=="0"){
            $('#ErrDistrictName').html("Please select District Name");
          $("#DistrictName").addClass("highlight_error"); 
            error++;
    }  else {
          $("#DistrictName").removeClass("highlight_error"); 
            $('#ErrDistrictName').html(""); 
    } 
    if ($('#AreaName').val()==""){
            $('#ErrAreaName').html("Please enter Area Name");
         $("#AreaName").addClass("highlight_error"); 
           error++;
    }  else {
        $("#AreaName").removeClass("highlight_error"); 
            $('#ErrAreaName').html(""); 
    } 
     if (error==0){
       $('#confirmationtoadd').modal("hide"); 
       $('#Success').modal("show");  
    }
}

function editform(){
     $('#confirmationtoedit').modal("show"); 
     
     $('#ErreditCode').html(""); 
     $('#ErreditCountryName').html(""); 
     $('#ErreditStateName').html(""); 
     $('#ErreditDistrictName').html(""); 
     $('#ErreditAreaName').html(""); 
     $('#ErreditRemarks').html("");
     
     $("#editCode").removeClass("highlight_error"); 
     $("#editCountryName").removeClass("highlight_error"); 
     $("#editStateName").removeClass("highlight_error"); 
     $("#editDistrictName").removeClass("highlight_error"); 
     $("#editAreaName").removeClass("highlight_error"); 
     $("#editRemarks").removeClass("highlight_error");
}

function edit(){
    var error = 0;
    if ($('#editCode').val()==""){
            $('#ErreditCode').html("Please enter Code");
          $("#editCode").addClass("highlight_error"); 
            error++;
    }  else {
         $("#editCode").removeClass("highlight_error"); 
            $('#ErrediCode').html(""); 
    }
     if ($('#editStateName').val()=="0"){
            $('#ErreditStateName').html("Please select State Name");
          $("#editStateName").addClass("highlight_error"); 
            error++;
    }  else {
         $("#editStateName").removeClass("highlight_error"); 
            $('#ErreditStateName').html(""); 
    }
      if ($('#editCountryName').val()=="0"){
            $('#ErreditCountryName').html("Please select Country Name");
         $("#editCountryName").addClass("highlight_error"); 
           error++;
    }  else {
        $("#editCountryName").removeClass("highlight_error"); 
            $('#ErreditCountryName').html(""); 
    } 
    if ($('#editDistrictName').val()=="0"){
            $('#ErreditDistrictName').html("Please select District Name");
          $("#editDistrictName").addClass("highlight_error"); 
            error++;
    }  else {
          $("#editDistrictName").removeClass("highlight_error"); 
            $('#ErreditDistrictName').html(""); 
    } 
    if ($('#editAreaName').val()==""){
            $('#ErreditAreaName').html("Please enter Area Name");
          $("#editAreaName").addClass("highlight_error"); 
            error++;
    }  else {
          $("#editAreaName").removeClass("highlight_error"); 
            $('#ErreditAreaName').html(""); 
    }  
     if (error==0){
       $('#confirmationtoedit').modal("hide"); 
       $('#Success').modal("show");  
    }
}

function viewform(){
     $('#confirmationtoview').modal("show"); 
}

 
function dashboard()  {
  location.href='dashboard.php';                                                              
}
 
//Character Limitations
 

/*Alphanumeric without space*/
var arr = ["Code","editCode"];
for (var i=0; i<arr.length; i++) {
    if ($('#'+arr[i]).length){
        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
            var keyCode = e.keyCode || e.which;
            if (e.ctrlKey || e.altKey) {
                e.preventDefault();
            } else {
                var notallowkeys = [48,49,50,51,52,53,54,55,56,57,188,190,191,59,220,221,222,219,173,61,192,111,106,109,107,46]
                var allowedkeys  = [96,97,98,99,100,101,102,103,104,105,9,8,16,46,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,48,49,50,51,52,53,54,55,56,57,33,34,35,36,37,38,39,40,45,12]
                if (e.shiftKey) {
                    if (notallowkeys.includes(keyCode)) {
                        e.preventDefault();
                    }
                } else {
                    if (!(allowedkeys.includes(keyCode))) {
                        e.preventDefault();
                    }
                }
            }
        });
        $('#'+arr[i]).on("cut copy paste",function(e){
            e.preventDefault();
        });  
    } 
}



/* Alphanumeric Space only correct */ 
var arr = ["AreaName","editAreaName"];
for (var i=0; i<arr.length; i++) {
    if ($('#'+arr[i]).length){
        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
            var keyCode = e.keyCode || e.which;
            console.log(e.keyCode);
            if (e.ctrlKey || e.altKey) {
                e.preventDefault();
            } else {
               var notallowkeys = [48,49,50,51,52,53,54,55,56,57,188,191,59,220,221,222,219,173,61,192,111,106,109,107,46]
                var allowedkeys  = [190,32,96,97,98,99,100,101,102,103,104,105,9,8,16,46,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,48,49,50,51,52,53,54,55,56,57,33,34,35,36,37,38,39,40,45,12]
                if (e.shiftKey) {
                    if (notallowkeys.includes(keyCode)) {
                        e.preventDefault();
                    }
                } else {
                    if (!(allowedkeys.includes(keyCode))) {
                        e.preventDefault();
                    }
                }
            }
        });
        $('#'+arr[i]).on("cut copy paste",function(e){
            e.preventDefault();
        });  
    } 
}

/* Alphnumeric and special characters, not allow !\$"'~  */
var arr = ["Remarks","editRemarks"];
for (var i=0; i<arr.length; i++) {
    if ($('#'+arr[i]).length){
        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
            var keyCode = e.keyCode || e.which;
            if (e.ctrlKey || e.altKey) {
                e.preventDefault();
            } else {
               var notallowkeys = [220,222,49,52,192]
               var allowedkeys  = [9,8,46,32,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,103,104,105,100,101,102,97,98,99,96,48,49,50,51,52,53,54,55,56,57,173,61,110,190,191,221,219,111,106,109,107,59,188]
               if (e.shiftKey) {
                    if (notallowkeys.includes(keyCode)) {
                        e.preventDefault();
                    }
                } else {
                    if (!(allowedkeys.includes(keyCode))) {
                        e.preventDefault();
                    }
                }
            }
        });
        $('#'+arr[i]).on("cut copy paste",function(e){
            e.preventDefault();
        });  
    } 
}    
</script>
    